@@ -25,11 +25,15 @@
 #include <QSqlQuery>
 #include <QSqlError>
 #include <QCoreApplication>
+#include <QDir>
+#include <QUrl>
 
 // Local
 #include <common/database/Database.h>
+#include <common/specialvalues.h>
 #include <utils/debug_and_return.h>
 #include <utils/qsqlquery_iterator.h>
+#include "kactivities-stats-logsettings.h"
 
 // Boost and STL
 #include <boost/range/algorithm/transform.hpp>
@@ -110,6 +114,14 @@ CREATE_GETTER_AND_SETTER(QStringList, linkedActivities, setLinkedActivities)
 
 #undef CREATE_GETTER_AND_SETTER
 
+QUrl ResultSet::Result::url() const
+{
+    if (QDir::isAbsolutePath(d->resource)) {
+        return QUrl::fromLocalFile(d->resource);
+    } else {
+        return QUrl(d->resource);
+    }
+}
 
 class ResultSetPrivate {
 public:
@@ -134,7 +146,7 @@ public:
               : QString()));
 
         if (query.lastError().isValid()) {
-            qWarning() << "[Error at ResultSetPrivate::initQuery]: " << query.lastError();
+            qCWarning(KACTIVITIES_STATS_LOG) << "[Error at ResultSetPrivate::initQuery]: " << query.lastError();
         }
     }
 
@@ -174,14 +186,25 @@ public:
 
     QString mimetypeClause(const QString &mimetype) const
     {
-        if (mimetype == QLatin1String(":any") || mimetype == QLatin1String("*")) return QStringLiteral("1");
+        if (mimetype == ANY_TYPE_TAG || mimetype == QLatin1String("*")) return QStringLiteral("1");
+
+        else if (mimetype == FILES_TYPE_TAG) return QStringLiteral("mimetype != 'inode/directory' AND mimetype != ''");
+        else if (mimetype == DIRECTORIES_TYPE_TAG) return QStringLiteral("mimetype = 'inode/directory'");
 
         return QStringLiteral("mimetype LIKE '") + Common::starPatternToLike(mimetype) + QStringLiteral("' ESCAPE '\\'");
     }
 
-    QString dateClause(QDate date) const {
-        return QStringLiteral("DATE(re.start, 'unixepoch') = '") +
-                               date.toString(Qt::ISODate) + QStringLiteral("' ");
+    QString dateClause(QDate start, QDate end) const {
+        if (end.isNull()) {
+            // only date filtering
+            return QStringLiteral("DATE(re.start, 'unixepoch') = '") +
+                    start.toString(Qt::ISODate) + QStringLiteral("' ");
+        } else {
+            // date range filtering
+            return QStringLiteral("DATE(re.start, 'unixepoch') >= '") +
+                    start.toString(Qt::ISODate) + QStringLiteral("' AND DATE(re.start, 'unixepoch') <= '") +
+                    end.toString(Qt::ISODate) + QStringLiteral("' ");
+        }
     }
 
     QString resourceEventJoinClause() const {
@@ -259,8 +282,8 @@ public:
 
         QString dateColumn = QStringLiteral("1"), resourceEventJoin;
         // WHERE clause for access date filtering and ResourceEvent table Join
-        if (!queryDefinition.date().isNull()) {
-            dateColumn = dateClause(queryDefinition.date());
+        if (!queryDefinition.dateStart().isNull()) {
+            dateColumn = dateClause(queryDefinition.dateStart(), queryDefinition.dateEnd());
 
             resourceEventJoin = resourceEventJoinClause();
         }
@@ -501,7 +524,7 @@ public:
         }
 
         result.setLinkedActivities(linkedActivities);
-        // qDebug() << result.resource() << "linked to activities" << result.linkedActivities();
+        // qDebug(KACTIVITIES_STATS_LOG) << result.resource() << "linked to activities" << result.linkedActivities();
 
         return result;
     }
@@ -515,7 +538,7 @@ ResultSet::ResultSet(Query queryDefinition)
     d->database = Database::instance(Database::ResourcesDatabase, Database::ReadOnly);
 
     if (!(d->database)) {
-        qWarning() << "KActivities ERROR: There is no database. This probably means "
+        qCWarning(KACTIVITIES_STATS_LOG) << "KActivities ERROR: There is no database. This probably means "
                       "that you do not have the Activity Manager running, or that "
                       "something else is broken on your system. Recent documents and "
                       "alike will not work!";
